@@ -1,24 +1,10 @@
+import os
+
 import pandas as pd
 from num2words import num2words
 import random
 import string
 
-#
-# path = f"datasets/T5_training Data.csv"
-#
-# df = pd.read_csv(path).dropna()
-# new_df = pd.DataFrame(data={"Sentences": [None], "UseCase": [None]})
-# for d in range(1, len(df)):
-#     try:
-#         Sentences = df[d - 1:d]["Sentences"]
-#         UseCase = df[d - 1:d]["UseCase"]
-#         Sentences1 = Sentences[d].split()[0]
-#         UseCase1 = UseCase[d].split()[0]
-#         new_df=new_df.append({"Sentences": Sentences[d], "UseCase": UseCase[d].replace(UseCase1, Sentences1)},ignore_index=True)
-#     except:
-#         pass
-# new_df.dropna().to_csv("datasets/T5_training Data new.csv")
-
 df = pd.DataFrame(data={"Sentences": [None], "UseCase": [None]})
 
 
@@ -31,6 +17,10 @@ def get_random_string(length):
 
 def create_training_data():
     global df
+    try:
+        os.mkdir("datasets")
+    except OSError as error:
+        pass
     usecases = ["range", "is_null", "not_null", "is_date", "is_not_date", "is_number", "is_not_number"]
     for usecase in usecases:
         if usecase == "range":
